@@ -5,21 +5,21 @@ from django.shortcuts import get_object_or_404
 from django.utils.decorators import method_decorator
 from django.views.generic import DetailView
 
+from invoicing.models import Invoice
 from invoicing.utils import import_name
 
-from models import Invoice
-
 
 class InvoiceDetailView(DetailView):
     model = Invoice
 
     @method_decorator(login_required)
     def dispatch(self, request, *args, **kwargs):
-        if not request.user.is_active or not request.user.is_superuser:
+        if not request.user.is_active and not request.user.is_superuser:
             return HttpResponseForbidden()
 
         invoice = get_object_or_404(self.model, pk=kwargs.get('pk', None))
 
-        formatter_class = import_name(getattr(settings, 'INVOICING_FORMATTER'))
+        invoicing_formatter = getattr(settings, 'INVOICING_FORMATTER', 'invoicing.formatters.html.BootstrapHTMLFormatter')
+        formatter_class = import_name(invoicing_formatter)
         formatter = formatter_class(invoice)
         return formatter.get_response()
